@@ -4,13 +4,12 @@ package Pinto::Server::Responder::File;
 
 use Moose;
 
-use Path::Class;
 use Plack::Response;
 use Plack::MIME;
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.049'; # VERSION
+our $VERSION = '0.50'; # VERSION
 
 #-------------------------------------------------------------------------------
 
@@ -21,18 +20,10 @@ extends qw(Pinto::Server::Responder);
 sub respond {
     my ($self) = @_;
 
+    # e.g. /stack_name/modules/02packages.details.txt.gz
     my (undef, @path_parts) = split '/', $self->request->path_info;
 
-    # HACK: The first element of @path_parts could be part of an
-    # actual path, or just a stack name (which we don't need).  We
-    # will assume that 'authors' and 'modules' are actual paths.
-    # Anything else is a stack name that can be discarded.
-    shift @path_parts if $path_parts[0] !~ m{^ (?:authors|modules) $}x;
-
-    # TODO: If a stack is specified, then check that the stack
-    # actually exists.  If not then return an error.
-
-    my $file = Path::Class::file($self->root, @path_parts);
+    my $file = $self->root->file(@path_parts);
 
     return [404, [], ["File $file not found"]] if not (-e $file and -f $file);
 
@@ -64,7 +55,7 @@ Pinto::Server::Responder::File - Responder for static files
 
 =head1 VERSION
 
-version 0.049
+version 0.50
 
 =head1 AUTHOR
 
